@@ -30,6 +30,7 @@
 (require 'riece-compat)
 (require 'riece-commands)
 (require 'riece-addon)
+(require 'riece-signal)
 
 (autoload 'derived-mode-class "derived")
 
@@ -151,7 +152,9 @@ If optional argument SAFE is nil, overwrite previous definitions."
     [backspace] scroll-down
     [return] scroll-up
     " " scroll-up
+    [home] beginning-of-buffer
     "$" end-of-buffer
+    [end] end-of-buffer
     "/" riece-command-raw
     ">" end-of-buffer
     "<" beginning-of-buffer
@@ -194,7 +197,9 @@ If optional argument SAFE is nil, overwrite previous definitions."
     [delete] riece-command-scroll-down
     [backspace] riece-command-scroll-down
     " " riece-command-scroll-up
+    [home] riece-command-beginning-of-buffer
     "$" riece-command-end-of-buffer
+    [end] riece-command-end-of-buffer
     ">" riece-command-next-channel
     "<" riece-command-previous-channel
     "\C-j" riece-command-next-channel
@@ -337,6 +342,7 @@ If optional argument CONFIRM is non-nil, ask which IRC server to connect."
     (setq riece-buffer-list (cdr riece-buffer-list)))
   (if riece-shrink-buffer-idle-timer
       (riece-cancel-timer riece-shrink-buffer-idle-timer))
+  (riece-clear-signal-slots)
   (setq riece-server nil
 	riece-current-channels nil
 	riece-current-channel nil
@@ -385,7 +391,7 @@ For a list of the generic commands type \\[riece-command-generic] ? RET.
      "^[]{}'`"))
 
   (run-hooks 'riece-command-mode-hook))
-  
+
 (defun riece-dialogue-mode ()
   "Major mode for displaying the IRC dialogue.
 All normal editing commands are turned off.
@@ -426,6 +432,7 @@ Instead, these commands are available:
 All normal editing commands are turned off.
 Instead, these commands are available:
 \\{riece-channel-mode-map}"
+  (make-local-variable 'riece-channel-buffer-window-point)
   (setq mode-line-buffer-identification
 	(riece-mode-line-buffer-identification
 	 '("Riece: "
@@ -441,7 +448,7 @@ All normal editing commands are turned off."
   (kill-all-local-variables)
   (buffer-disable-undo)
   (setq major-mode 'riece-channel-list-mode
-        mode-name "Channels"
+	mode-name "Channels"
 	mode-line-buffer-identification
 	(riece-mode-line-buffer-identification '("Riece: "))
 	truncate-lines t
@@ -460,7 +467,7 @@ Instead, these commands are available:
   (kill-all-local-variables)
   (buffer-disable-undo)
   (setq major-mode 'riece-user-list-mode
-        mode-name "Users"
+	mode-name "Users"
 	mode-line-buffer-identification
 	(riece-mode-line-buffer-identification
 	 '("Riece: " riece-long-channel-indicator " "))
@@ -485,7 +492,7 @@ Instead, these commands are available:
 		    (eq major-mode (nth 2 (car alist))))
 	  (funcall (nth 2 (car alist))))
 	(setq alist (cdr alist))))))
-      
+
 (provide 'riece)
 
 ;;; riece.el ends here
